{% extends 'allianceauth/base.html' %}
{% load i18n %}

{% block page_title %}{% trans title %}{% endblock %}

{% block content %}    
    <h2 class="text-center">{{ title }}</h2>
    <div class="col-lg-12 container">            
        {% block details %}{% endblock %}
    </div>
{% endblock %}
