{% extends "structuretimers/timer_edit.html" %}
{% load i18n %}

{% block page_title %}
    {% trans "Create Timer" %}
{% endblock page_title %}

{% block page_header %}
    {% trans "Create Structure Timer" %}
{% endblock %}

{% block submit_button_text %}
    {% trans "Create Timer" %}
{% endblock %}
